@@ -24,16 +24,12 @@ def setup_module(module):
     except:
         pass
 
-    # adjust relative paths to account for instancer's chdir operation
-    instance_tiddlers = []
-    for collection in tww.manage.config['instance_tiddlers']:
-        bag = collection[0]
-        uris = collection[1]
-        collection = (bag, [
+    # adjust relative paths to account for instancer's chdir operation -- XXX: obsolete?
+    instance_tiddlers = tww.manage.config['instance_tiddlers']
+    for bag, uris in instance_tiddlers.items():
+        instance_tiddlers[bag] = [
             uri.replace('file:./', 'file:../') for uri in uris
-            ])
-        instance_tiddlers.append(collection)
-    tww.manage.config['instance_tiddlers'] = instance_tiddlers
+            ]
 
 
 class TestInstance(object):
@@ -47,7 +43,7 @@ class TestInstance(object):
         rmtree(instance_dir)
 
     def test_create_tiddlywebwiki_instance(self):
-        tww.instancer.instance(instance_dir)
+        tww.instancer.instance(instance_dir, system_config=config)
 
         contents = _get_file_contents('../%s/tiddlywebconfig.py' % instance_dir)
 
@@ -55,7 +51,7 @@ class TestInstance(object):
         assert "'twanager_plugins': ['tiddlywebwiki']" in contents
 
     def test_create_bag_policies(self):
-        tww.instancer.instance(instance_dir)
+        tww.instancer.instance(instance_dir, config)
 
         bag = Bag('system')
         system_policy = self.store.get(bag).policy
