@@ -37,14 +37,9 @@ except ImportError:
 
 config = {
         'base_tiddlywiki': BASE_TIDDLYWIKI,
-        'twanager_plugins': [
-            'tiddlywebwiki.importer',
-            'tiddlywebwiki.instancer',
-            'tiddlywebwiki.manage'
-            ],
-        'instance_tiddlers': [
-            ('system', CLIENT_PLUGINS),
-            ],
+        'instance_tiddlers': {
+            'system': CLIENT_PLUGINS
+            },
         'extension_types': {
             'wiki': 'text/x-tiddlywiki',
             },
